#!/usr/bin/env node

const fs = require('fs')
const program = require('commander')
const inquirer = require('inquirer')
const classStub = require('./lib/stubs/classComponent')
const functionStub = require('./lib/stubs/functionComponent')
const path = './src/admin/modules'

function createFile(name, type, filePath){
  createDir(name, filePath, function(dirName){
    fs.writeFile(`./${filePath}/components/${dirName}/${name}.js`, type === 'Class Component' ? classStub(name) : functionStub(name), function(err) {
      if(err) {
          console.log(err);
      }
      console.log("The file was saved!");
    }); 
  })
}

function createDir(name, dirPath, callback) {
  fs.mkdir(`./${dirPath}/components/${name}`, function(err){
    if(err){
      console.log(`Failed to create ${name} component`)
      return false
    }
    callback(name)
  })
}

function getDirectories() {
  return fs.readdirSync(path).filter(function (file) {
    return file
  });
}

function version() {
  const packagejson = require('./package.json');
  console.log(packagejson.version);
}

function createComponent(name){
  inquirer.prompt([
    {type: 'list', name: 'type', message: 'Please select a component type', choices: ['Class Component', 'Function Component']},
    {type: 'rawlist', name: 'module', message: 'select a module', choices: getDirectories().concat('Create new module...')}
  ]).then((answers) => {
    if(answers.module === 'Create new module...'){
      inquirer.prompt([
        {type: 'input', name: 'new_module', message: 'Enter new module name'}
      ]).then((answers) => {
        
      })
    }
    else {
      createFile(name, answers.type, path + '/' + answers.module)
    }
  })
}

program.command('version')
        .alias('v')
        .description('Displays dy-foundation-cli version')
        .action(() => {
          version()
        })
        
program.command('create-component <name>')
        .alias('cr')
        .option('-s, --store', 'Connect component to redux store')
        .description('Creates a new component')
        .action((name) => {
          createComponent(name)
        })

program.parse(process.argv);